<?php
/**
 * WooCommerce Hooks
 *
 * @package Theme Palace
 * @subpackage ETC Pro
 * @since ETC Pro 1.0.0
 */

/**
 * Make theme WooCommerce ready
 */

function etc_pro_woocommerce_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'etc_pro_woocommerce_setup' );


remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);
remove_action( 'woocommerce_before_main_content','woocommerce_breadcrumb', 20 );
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );
remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
remove_action( 'wp_footer', 'woocommerce_demo_store' );

add_action( 'wp_head', 'woocommerce_demo_store', 999 );
add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 15 );
add_action('woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_link_open', 5);
add_action('woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 20);
$archive_pagination = get_theme_mod( 'etc_pro_archive_pagination_type', 'numeric' );
if ( 'infinite_scroll' !== $archive_pagination ) {
	add_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 30 );
}

// change custom wrapper
add_action('woocommerce_before_main_content', 'etc_pro_before_main_content', 10);
if ( ! function_exists('etc_pro_before_main_content')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_before_main_content() { 
		if ( is_product() ) : ?>
			<div class="wrapper singular-section page-section">
		<?php else : ?>
			<div id="inner-content-wrapper">
		<?php endif;
	}
}

// change custom wrapper end
add_action('woocommerce_after_main_content', 'etc_pro_after_main_content', 10);
if ( ! function_exists('etc_pro_after_main_content')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_after_main_content() { ?>
		</div>
	<?php }
}

// change custom filter wrapper end
add_action('woocommerce_before_shop_loop', 'etc_pro_before_filtering_wrapper', 5);
if ( ! function_exists('etc_pro_before_filtering_wrapper')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_before_filtering_wrapper() { ?>
		<div class="woocommerce-filtering clear">
	<?php }
}

// change custom filter wrapper end
add_action('woocommerce_before_shop_loop', 'etc_pro_after_filtering_wrapper', 40);
if ( ! function_exists('etc_pro_after_filtering_wrapper')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_after_filtering_wrapper() { ?>
		</div>
	<?php }
}

// change custom filter wrapper end
add_action('woocommerce_before_shop_loop', 'etc_pro_before_loop_start_wrapper', 50);
if ( ! function_exists('etc_pro_before_loop_start_wrapper')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_before_loop_start_wrapper() { ?>
		<div id="infinite-post-wrap" class="post-archive grid">
	<?php }
}

// change custom filter wrapper end
add_action('woocommerce_after_shop_loop', 'etc_pro_after_loop_wrapper', 20);
if ( ! function_exists('etc_pro_after_loop_wrapper')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_after_loop_wrapper() { ?>
		</div>
	<?php }
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'etc_pro_loop_columns');
if ( ! function_exists('etc_pro_loop_columns')) {
	/**
	 * Shop Page no. of column
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_loop_columns() {
		return 4; // 4 products per row
	}
}

// Change post thumbnail size
add_filter('single_product_archive_thumbnail_size', 'etc_pro_product_archive_thumbnail');
if ( ! function_exists('etc_pro_product_archive_thumbnail')) {
	/**
	 * Shop Page no. of column
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_product_archive_thumbnail() {
		return 'medium_large'; 
	}
}

// change custom thumbnail wrapper end
add_action('woocommerce_before_shop_loop_item_title', 'etc_pro_before_thumbnail_wrapper', 5);
if ( ! function_exists('etc_pro_before_thumbnail_wrapper')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_before_thumbnail_wrapper() { ?>
		<div class="post-thumbnail">
			<a href="<?php the_permalink(); ?>">
	<?php }
}

// change custom thumbnail wrapper end
add_action('woocommerce_before_shop_loop_item_title', 'etc_pro_after_thumbnail_wrapper', 20);
if ( ! function_exists('etc_pro_after_thumbnail_wrapper')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_after_thumbnail_wrapper() { ?>
			</a>
		</div>
	<?php }
}

// change wrapper
add_action('woocommerce_before_shop_loop_item_title', 'etc_pro_before_entry_container_wrapper', 30);
if ( ! function_exists('etc_pro_before_entry_container_wrapper')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_before_entry_container_wrapper() { ?>
		<div class="entry-container">
	<?php }
}

// change 
add_action('woocommerce_before_shop_loop_item_title', 'etc_pro_entry_container_categories', 40);
if ( ! function_exists('etc_pro_entry_container_categories')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_entry_container_categories() { ?>
		<div class="product-meta">
			<div class="cat-links">
				<?php echo wc_get_product_category_list( get_the_id(), ', ' ); ?>
			</div>
		</div>
	<?php }
}

// entry container closing
add_action('woocommerce_after_shop_loop_item', 'etc_pro_after_entry_container_wrapper', 30);
if ( ! function_exists('etc_pro_after_entry_container_wrapper')) {
	/**
	 * custom wrapper
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_after_entry_container_wrapper() { ?>
		</div>
	<?php }
}

function etc_pro_woocommerce_post_classes( $classes ) {
	if ( is_woocommerce() ) {
		$classes[] = 'grid-item';
	}
  
	return $classes;
}
add_filter( 'post_class', 'etc_pro_woocommerce_post_classes' );
add_filter( 'product_cat_class', 'etc_pro_woocommerce_post_classes' );


add_filter( 'woocommerce_show_page_title', 'etc_pro_remove_page_title' );
if ( ! function_exists('etc_pro_remove_page_title')) {
	/**
	 * Shop Page product start
	 *
	 * @since ETC Pro 1.0.0
	 *
	 */
	function etc_pro_remove_page_title() {
		return false;
	}
}

function etc_pro_woocommerce_pagination_posts($query){
	$front_page_id        = get_option( 'page_on_front' );
    $current_page_id      = $query->get( 'page_id' );
    $is_static_front_page = 'page' == get_option( 'show_on_front' );
    if ( $is_static_front_page && $front_page_id == $current_page_id  ) {
    	return;
	}
	if ( is_shop() || is_product_category() || is_product_tag() ) {
	    if ( $query->is_main_query() && ! is_admin() ) {
	        $query->set( 'posts_per_page', get_option( 'posts_per_page' ) );
	    }
	}
}
add_action('pre_get_posts','etc_pro_woocommerce_pagination_posts');
